@@ -20,9 +20,17 @@
 #ifndef ERRORBOX_H
 #define ERRORBOX_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 extern void gpe_error_box (const char *text);
 extern void gpe_error_box_nonblocking (const char *text);
 extern void gpe_perror_box (const char *text);
 extern void gpe_error_box_fmt (const char *format, ...);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif
